
# (b) Chill coma onset temperature analysis

# I placed the beetles in individual 50 mL tubes mounted to a rack then submerged in a cooling bath. 
# The cooling bath started at 20 degrees C and was cooling at a rate of 0.1 degree C per minute.
# I monitored the beetles every minute and recorded at what temperature they lost the ability to move 
# if they appeared to be immobile, I gently tapped the side of their tube to try to stimulate movement

library(tidyverse)
library(MuMIn)
library(predictmeans)
options(na.action = "na.fail") #prevent fitting models to different datasets

#load dataset (b_chill_coma_onset_data.csv)
ctmin.dat <- read.csv(file.choose())
summary(ctmin.dat)
head(ctmin.dat)
tail(ctmin.dat)

#check distribution of ctmin
hist(ctmin.dat$ctmin)
shapiro.test(ctmin.dat$ctmin)
hist(ctmin.dat$mass.g)
shapiro.test(ctmin.dat$mass.g)
ctmin.dat$species.round <- as.factor(ctmin.dat$species.round)

ctmod1 <- glm(ctmin ~ species.round*mass.g, family = gaussian, ctmin.dat)
plot(ctmod1)
plot(resid(ctmod1) ~ ctmin.dat$species.round)
bartlett.test(resid(ctmod1), ctmin.dat$species.round)
plot(resid(ctmod1) ~ ctmin.dat$mass.g)
hist(resid(ctmod1))
# not a great fit, but can't find suitable transformations to fix everything
# results with different transformations (below) are similar

ctmod10 <- dredge(ctmod1, rank="AICc")
ctmod10
subset(ctmod10, delta<2)

ct.best.model <- glm(ctmin ~ species.round, family = gaussian,  ctmin.dat)
plot(ct.best.model)
plot(resid(ct.best.model) ~ ctmin.dat$species.round)
bartlett.test(resid(ct.best.model), ctmin.dat$species.round)
plot(resid(ct.best.model) ~ ctmin.dat$mass.g)
qqnorm(resid(ct.best.model)) 
CookD(ct.best.model, newwd=FALSE) 
hist(resid(ct.best.model))

# try an alternate fit
min(ctmin.dat$ctmin)
hist(sqrt(ctmin.dat$ctmin+3.3))
ctmin.dat$sqrt.ctmin <- sqrt(ctmin.dat$ctmin+3.3)

library(nlme)
library(predictmeans)
ctmod1.1 <- gls(sqrt.ctmin ~ species.round*mass.g, ctmin.dat)
ctmod1.2 <- gls(sqrt.ctmin ~ species.round*mass.g, weights = varIdent(form =~ 1|species.round), ctmin.dat)
AIC(ctmod1.1, ctmod1.2)
plot(ctmod1.2)
plot(resid(ctmod1.2, type = "normalized") ~ ctmin.dat$species.round)
bartlett.test(resid(ctmod1.2, type = "normalized"), ctmin.dat$species.round)
plot(resid(ctmod1.2) ~ ctmin.dat$mass.g)
qqnorm(resid(ctmod1.2)) 
CookD(ctmod1.2, newwd=FALSE) 
hist(resid(ctmod1.2, type = "normalized"))

ctmod1.2.ML <- gls(sqrt.ctmin ~ species.round*mass.g, weights = varIdent(form =~ 1|species.round), method = "ML", ctmin.dat)
ctmod10.2 <- dredge(ctmod1.2.ML, rank="AICc")
ctmod10.2
subset(ctmod10.2, delta<2)

ct.best.model.2 <- gls(sqrt.ctmin ~ species.round, weights = varIdent(form =~ 1|species.round), method = "ML", ctmin.dat)
plot(ct.best.model.2)
plot(resid(ct.best.model.2, type = "normalized") ~ ctmin.dat$species.round)
bartlett.test(resid(ct.best.model.2, type = "normalized"), ctmin.dat$species.round)
plot(resid(ct.best.model.2, type = "normalized") ~ ctmin.dat$mass.g)
qqnorm(resid(ct.best.model.2, type = "normalized")) 
CookD(ct.best.model.2, newwd=FALSE) 
hist(resid(ct.best.model.2, type = "normalized"))

summary(ct.best.model) 
summary(ct.best.model.2) 
# similar results

# report results from first glm
summary(ct.best.model) # intercept = orbicollis_july
# orb round 3 vs orb round 2, t=-3.78, p<0.001
# orb round 3 vs sayi round 1, t=-9.66, p<0.0001
# orb round 3 vs sayi round 2, t=-7.35, p<0.0001
# orb round 3 vs sayi round 3, t=-1.67, p=0.10

ctmin.dat$species.round2[ctmin.dat$species.round == "orbicollis_june"]<-"a_orbicollis_june"
ctmin.dat$species.round2[ctmin.dat$species.round == "orbicollis_july"]<-"orbicollis_july"
ctmin.dat$species.round2[ctmin.dat$species.round == "sayi_june"]<-"sayi_june"
ctmin.dat$species.round2[ctmin.dat$species.round == "sayi_may"]<-"sayi_may"
ctmin.dat$species.round2[ctmin.dat$species.round == "sayi_july"]<-"sayi_july"
ctmin.dat$species.round2

ctmod2 <- glm(ctmin ~ species.round2, family=gaussian, ctmin.dat)
summary(ctmod2) # intercept = orbicollis_june
# orb round 2 vs sayi round 1, t=-5.88, p<0.0001
# orb round 2 vs sayi round 2, t=-3.57, p<0.001
# orb round 2 vs sayi round 3, t=2.11, p=0.04

ctmin.dat$species.round3[ctmin.dat$species.round == "orbicollis_june"]<-"orbicollis_june"
ctmin.dat$species.round3[ctmin.dat$species.round == "orbicollis_july"]<-"orbicollis_july"
ctmin.dat$species.round3[ctmin.dat$species.round == "sayi_june"]<-"a_sayi_june"
ctmin.dat$species.round3[ctmin.dat$species.round == "sayi_may"]<-"sayi_may"
ctmin.dat$species.round3[ctmin.dat$species.round == "sayi_july"]<-"sayi_july"
ctmin.dat$species.round3

ctmod3 <- glm(ctmin ~ species.round3, family=gaussian, ctmin.dat)
summary(ctmod3) # intercept = sayi_june
# sayi round 2 vs sayi round 1, t=-2.31, p=0.026
# sayi round 2 vs sayi round 3, t=5.68, p<0.0001

ctmin.dat$species.round4[ctmin.dat$species.round == "orbicollis_june"]<-"orbicollis_june"
ctmin.dat$species.round4[ctmin.dat$species.round == "orbicollis_july"]<-"orbicollis_july"
ctmin.dat$species.round4[ctmin.dat$species.round == "sayi_june"]<-"sayi_june"
ctmin.dat$species.round4[ctmin.dat$species.round == "sayi_may"]<-"a_sayi_may"
ctmin.dat$species.round4[ctmin.dat$species.round == "sayi_july"]<-"sayi_july"
ctmin.dat$species.round4

ctmod4 <- glm(ctmin ~ species.round4, family=gaussian, ctmin.dat)
summary(ctmod4) # intercept = sayi_may
# sayi round 1 vs sayi round 3, t=7.99, p<0.0001

########################
#Plot data

#Reorder "species.round" for the boxplot
ctmin.dat$species.round <- factor(ctmin.dat$species.round, levels = c('sayi_may', 'sayi_june', 
                                                  'orbicollis_june', 'sayi_july', 
                                                  'orbicollis_july'), ordered = TRUE)

class(ctmin.dat$species.round)

ctmin.fig <- ggplot(ctmin.dat, aes(x=species.round, y=ctmin, fill=species))+
  geom_boxplot()+
  scale_fill_manual(values=c('orange1','mediumpurple4'))+
  scale_x_discrete(labels=c("N. sayi (Round 1)", "N. sayi (Round 2)", "N. orbicollis (Round 2)", 
                            "N. sayi (Round 3)", "N. orbicollis (Round 3)")) + 
  labs(title= "Critical Thermal Minimum") +
  scale_y_continuous(name="CTmin (degrees C)")

ctmin.fig + theme_bw()+theme(legend.position = c(0.87, 0.22)) # figure 1c

#######################################
