
# (c) Chill coma recovery time analysis

# I placed 10 individuals of each species in an ice water bath (0 degrees C) for 6 hours. 
# The beetles were removed from the bath and transferred onto the bench in the lab (recovery temp 22 C)
# I recorded the time it took them to recover from their chill coma as the time in seconds that it took 
# each individual to right themselves (flip from their back onto their front)

library(tidyverse)
library(MuMIn)
options(na.action = "na.fail") #prevent fitting models to different datasets

#load dataset (c_chill_coma_recovery_data.csv)
ccrt.dat <- read.csv(file.choose())
summary(ccrt.dat)
head(ccrt.dat)
tail(ccrt.dat)
str(ccrt.dat)

hist(ccrt.dat$ccrt)
shapiro.test(ccrt.dat$ccrt)
#ccrt not normally distributed
#log transform and test for normality
ccrt.dat["log.ccrt"] <- log(ccrt.dat$ccrt)
hist(ccrt.dat$log.ccrt)
shapiro.test(ccrt.dat$log.ccrt) #ok

ccrt.dat$species.round <- as.factor(ccrt.dat$species.roun)
hist(ccrt.dat$mass.g)
shapiro.test(ccrt.dat$mass.g) #ok

ccrtmod <- glm(log.ccrt ~ species.round * mass.g, family=gaussian, ccrt.dat)
plot(ccrtmod)
plot(resid(ccrtmod) ~ ccrt.dat$species.round)
bartlett.test(resid(ccrtmod), ccrt.dat$species.round)
plot(resid(ccrtmod) ~ ccrt.dat$mass.g)
hist(resid(ccrtmod))

ccrt.mod1.all <-dredge(ccrtmod, rank="AICc")
ccrt.mod1.all
subset(ccrt.mod1.all, delta<2)

ccrtmod.best <- glm(log.ccrt ~ species.round, family=gaussian, ccrt.dat)
plot(ccrtmod.best)
plot(resid(ccrtmod.best) ~ ccrt.dat$species.round)
bartlett.test(resid(ccrtmod.best), ccrt.dat$species.round)
plot(resid(ccrtmod.best) ~ ccrt.dat$mass.g)
hist(resid(ccrtmod.best))

summary(ccrtmod.best) # intercept = orbicollis_july
# orb round 3 vs orb round 2, t=-3.649, p<0.001
# orb round 3 vs sayi round 1, t=-5.01, p<0.0001
# orb round 3 vs sayi round 2, t=-0.72, p=0.48
# orb round 3 vs sayi round 3, t=-0.71, p=0.48

ccrt.dat$species.round2[ccrt.dat$species.round == "orbicollis_june"]<-"a_orbicollis_june"
ccrt.dat$species.round2[ccrt.dat$species.round == "orbicollis_july"]<-"orbicollis_july"
ccrt.dat$species.round2[ccrt.dat$species.round == "sayi_june"]<-"sayi_june"
ccrt.dat$species.round2[ccrt.dat$species.round == "sayi_may"]<-"sayi_may"
ccrt.dat$species.round2[ccrt.dat$species.round == "sayi_july"]<-"sayi_july"
ccrt.dat$species.round2

ccrtmod2 <- glm(log.ccrt ~ species.round2, family=gaussian, ccrt.dat)
summary(ccrtmod2) # intercept = orbicollis_june
# orb round 2 vs sayi round 1, t=-1.36, p=0.18
# orb round 2 vs sayi round 2, t=2.93, p0.005
# orb round 2 vs sayi round 3, t=2.04, p=0.005

ccrt.dat$species.round3[ccrt.dat$species.round == "orbicollis_june"]<-"orbicollis_june"
ccrt.dat$species.round3[ccrt.dat$species.round == "orbicollis_july"]<-"orbicollis_july"
ccrt.dat$species.round3[ccrt.dat$species.round == "sayi_june"]<-"a_sayi_june"
ccrt.dat$species.round3[ccrt.dat$species.round == "sayi_may"]<-"sayi_may"
ccrt.dat$species.round3[ccrt.dat$species.round == "sayi_july"]<-"sayi_july"
ccrt.dat$species.round3

ccrtmod3 <- glm(log.ccrt ~ species.round3, family=gaussian, ccrt.dat)
summary(ccrtmod3) # intercept = sayi_june
# sayi round 2 vs sayi round 1, t=-4.29, p<0.0001
# sayi round 2 vs sayi round 3, t=0.007, p=0.99

ccrt.dat$species.round4[ccrt.dat$species.round == "orbicollis_june"]<-"orbicollis_june"
ccrt.dat$species.round4[ccrt.dat$species.round == "orbicollis_july"]<-"orbicollis_july"
ccrt.dat$species.round4[ccrt.dat$species.round == "sayi_june"]<-"sayi_june"
ccrt.dat$species.round4[ccrt.dat$species.round == "sayi_may"]<-"a_sayi_may"
ccrt.dat$species.round4[ccrt.dat$species.round == "sayi_july"]<-"sayi_july"
ccrt.dat$species.round4

ccrtmod4 <- glm(log.ccrt ~ species.round4, family=gaussian, ccrt.dat)
summary(ccrtmod4) # intercept = sayi_may
# sayi round 1 vs sayi round 3, t=4.30, p<0.0001

########################
#Plot data

#Reorder "species.round" for the boxplot
ccrt.dat$species.round <- factor(ccrt.dat$species.round, levels = c('sayi_may', 'sayi_june', 
                                                  'orbicollis_june', 'sayi_july', 
                                                  'orbicollis_july'), ordered = TRUE)

ccrt.fig <- ggplot(ccrt.dat, aes(x=species.round, y=ccrt, fill=species))+
  geom_boxplot()+
  scale_fill_manual(values=c('orange1','mediumpurple4'))+
  scale_x_discrete(labels=c("N. sayi (Round 1)", "N. sayi (Round 2)", "N. orbicollis (Round 2)", 
                            "N. sayi (Round 3)", "N. orbicollis (Round 3)")) + 
  labs(title= "Chill Coma Recovery Time") +
  scale_y_continuous(name="Chill Coma Recovery Time (s)")
ccrt.fig + theme_bw()+theme(legend.position="none") # figure 1d

#######################################
