
# (e) N. orbicollis breeding activity - temperature assay

# Fur removal examined for N. orbicollis (alone) for temperatures ranging from 2.5C to 17.5C.

#load dataset (e_orbicollis_fur_removal_exp.csv)
orb.fur.dat <- read.csv(file.choose()) # use dialog box to import data file 
names(orb.fur.dat) # lists all variable names

orb.fur.dat$sex<-as.factor(orb.fur.dat$sex)
is.factor(orb.fur.dat$sex)
hist(orb.fur.dat$fur.area.removed)
orb.fur.dat$fur.rem<-as.integer(orb.fur.dat$fur.area.removed)
hist(orb.fur.dat$fur.rem)
hist(orb.fur.dat$mouse.mass)
hist(orb.fur.dat$beetle.mass)

library(MASS)
library(countreg) #Kleiber, C. and Zeileis, A., 2016. Visualizing count fur.data regressions using rootograms. The American Statistician, 70(3), pp.296-303.
model.orb.po <- glm(fur.rem ~ beetle.mass + mouse.mass + temp.C + beetle.mass:temp.C + mouse.mass:temp.C, data = orb.fur.dat, family=poisson)
model.orb.nb <- glm.nb(fur.rem ~ beetle.mass + mouse.mass + temp.C + beetle.mass:temp.C + mouse.mass:temp.C, data = orb.fur.dat)
model.orb.zip <- zeroinfl(fur.rem ~ beetle.mass + mouse.mass + temp.C + beetle.mass:temp.C  + mouse.mass:temp.C | 1, data = orb.fur.dat)
model.orb.zinb <- zeroinfl(fur.rem ~ beetle.mass + mouse.mass + temp.C + beetle.mass:temp.C  + mouse.mass:temp.C | 1, data = orb.fur.dat, dist = "negbin")

countreg::rootogram(model.orb.po, style = "hanging")
countreg::rootogram(model.orb.nb, style = "hanging")
countreg::rootogram(model.orb.zip, style = "hanging")
countreg::rootogram(model.orb.zinb, style = "hanging")
plot(model.orb.po)
plot(model.orb.nb)
# model.orb.zinb seems to be the best fit

# compare models with different predictors using information-theoretic approach with MuMIn package; rank models by delta AICc
library(MuMIn)
options(na.action = "na.fail")   #  prevent fitting models to different comp.datasets
m.orb.zinb <- dredge(model.orb.zinb, rank = "AICc") 
subset(m.orb.zinb, delta<2) #subset of models where delta QAICc <2

model.orb.zinb.best <- zeroinfl(fur.rem ~ beetle.mass + temp.C | 1, data = orb.fur.dat, dist = "negbin")

countreg::rootogram(model.orb.zinb.best, style = "hanging")
summary(model.orb.zinb.best)

##################
# Plot raw data

library(ggplot2)
theme_bw.2<-theme_bw() + theme(legend.direction="horizontal", legend.position=c(0.5,1.047), legend.title=element_blank())
orb.fur.boxplot<-ggplot(orb.fur.dat, aes(y = fur.area.removed, x = factor(temp.C))) + geom_boxplot(fill="orange1") + 
  geom_point(position = position_jitter(width=0.2,height=0), size=2.0)
orb.fur.boxplot + theme_bw.2 # figure 3b


##################################################################
