
# (g) Field experiments - N. sayi - N. orbicollis traps with mouse carcasses at QUBS (2019)

# Do sayi and orbicollis show differences in seasonal use of mouse carcasses?

#load dataset (g_dataset.beetle.size.differences.2019.csv)
exp.2019.dat <- read.csv(file.choose()) # use dialog box to import data file 
names(exp.2019.dat) # lists all variable names
head(exp.2019.dat)
exp.2019.dat$owner.sat <- as.factor(exp.2019.dat$owner.sat)
exp.2019.dat$sat.present <- as.factor(exp.2019.dat$sat.present)
exp.2019.dat$sayi.and.orb <- as.factor(exp.2019.dat$sayi.and.orb)
exp.2019.dat$owner.spp <- as.factor(exp.2019.dat$owner.spp)
exp.2019.dat$species <- as.factor(exp.2019.dat$species)
exp.2019.dat$block <- as.factor(exp.2019.dat$block)
exp.2019.dat$trap <- as.factor(exp.2019.dat$trap)

# (A) Carcass Owners
exp.2019.dat1 = exp.2019.dat[!duplicated(exp.2019.dat$block),]
exp.2019.dat1$owner.spp <- factor(exp.2019.dat1$owner.spp, levels = c("sayi", "orbicollis"))
model.owners <- glm(owner.spp ~ cal.date.set, family = binomial, data = exp.2019.dat1)

#check model fit
#don't need to worry about over- or under-dispersion (http://stats.stackexchange.com/questions/92156/how-to-handle-underdispersion-in-glmm-binomial-outcome-variable)
library(heatmapFit)
pred<-predict(model.owners,type="response")
heatmap.fit(model.owners$y,pred,reps=1000)
summary(model.owners)

pred.1 <- predict(model.owners, se.fit = TRUE, type="link") 
data1 <- data.frame(exp.2019.dat1, pred.1)
names(data1)
linkinv <- family(model.owners)$linkinv ## inverse-link function
data1$pred.backfit <- linkinv(data1$fit)
alpha <- 0.95
sc <- abs(qnorm((1-alpha)/2))  ## Normal approx. to likelihood
data1$lwr <- linkinv(data1$fit - sc*data1$se.fit) #lower 95%CL 
data1$upr <- linkinv(data1$fit + sc*data1$se.fit) #upper 95%CL 

# create plot - transformed data
library(ggplot2)
theme_bw.2 <- theme_bw() + theme(legend.direction="horizontal", legend.position=c(0.82,0.85), legend.title=element_blank())
data1$pattern[data1$owner.spp == "orbicollis"] <- 1
data1$pattern[data1$owner.spp == "sayi"] <- 0
is.numeric(data1$pattern)

pred.1 <- ggplot(data1, aes(x=cal.date.set, y=pattern, colour=owner.spp)) +
  ggtitle("Owner of mouse carcass") +
  xlab("Calendar date") +
  ylab("Mouse owner") +
  xlim(c(133, 200)) + 
  ylim(c(0,1)) + 
  geom_ribbon(aes(ymin=lwr,ymax=upr),fill="grey80",colour=NA) +
  geom_line(aes(y=pred.backfit),size=1, colour="black") +
  geom_abline(intercept = 0.5, slope = 0, linetype="dotted") +
  geom_count(mapping=NULL, data=NULL, stat = "sum", position = "identity", inherit.aes = TRUE, shape=1, show.legend=FALSE) +
  scale_size_area() +
  scale_color_manual(values=c('mediumpurple4', 'orange1'))
pred.1 + theme_bw.2 # export 4 x 5 landscape; figure 5a


# (B) Numbers of beetles per trap (both carcass owners and satellites)
exp.2019.dat2 <- subset(exp.2019.dat, exp.2019.dat$species != "hebes") #keep only sayi and orbicollis
summary(exp.2019.dat2$species)
model.all <- glm(species ~ cal.date.set, family = binomial, data = exp.2019.dat2)

#check model fit
#don't need to worry about over- or under-dispersion (http://stats.stackexchange.com/questions/92156/how-to-handle-underdispersion-in-glmm-binomial-outcome-variable)
library(heatmapFit)
pred<-predict(model.all,type="response")
heatmap.fit(model.all$y,pred,reps=1000)
summary(model.all)


## xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
# (2) Are carcass owners larger than satellites?

exp.2019.dat3 <- subset(exp.2019.dat, exp.2019.dat$sat.present == "yes") # use dialog box to import data file 
head(exp.2019.dat3) # lists all variable names

hist(exp.2019.dat3$mass.g)
hist(exp.2019.dat3$mass.g ^ (1/3)) # linearize using cube-root transformation
exp.2019.dat3$cubemass <- exp.2019.dat3$mass.g^(1/3)
exp.2019.dat3$owner.sat <- as.factor(exp.2019.dat3$owner.sat)
exp.2019.dat3$block <- as.factor(exp.2019.dat3$block)

library(nlme)
model.mass <- lme(cubemass ~ owner.sat, random =~ 1|block, data = exp.2019.dat3)
plot(model.mass)
bartlett.test(resid(model.mass), exp.2019.dat3$owner.sat)
plot(resid(model.mass) ~ exp.2019.dat3$owner.sat)
hist(resid(model.mass))
shapiro.test(resid(model.mass))
summary(model.mass)

box1<- ggplot(data=exp.2019.dat3, aes(x=owner.sat, y=cubemass)) +
  geom_boxplot() + geom_point(position= position_jitter(width=0.2), size=2.5, colour="darkgray") +
  theme_bw(base_size = 12, base_family = "Helvetica") +
  labs(x = " ", y= "Mass (g, cube-root transformed)") +
  ggtitle("Size differences between owners and satellites") 
box1 + theme_bw.2 # alternative figure

# calculate the mean and max mass for owners and satellites within each bucket
library(dplyr)
owner.sat.ave.mass <- exp.2019.dat3 %>% group_by(block, owner.sat) %>% summarise(mean_mass = mean(mass.g))
owner.sat.max.mass <- exp.2019.dat3 %>% group_by(block, owner.sat) %>% summarise(max_mass = max(mass.g))

owner.sat.mass <- merge(owner.sat.ave.mass, owner.sat.max.mass, by = 'block')

library(tidyr) # reshape for plotting
owner.sat.ave.mass2 <-  spread(owner.sat.ave.mass, owner.sat, c(mean_mass))
owner.sat.max.mass2 <-  spread(owner.sat.max.mass, owner.sat, c(max_mass))
owner.sat.mass <- merge(owner.sat.ave.mass2, owner.sat.max.mass2, by = 'block')
owner.sat.mass
colnames(owner.sat.mass)[colnames(owner.sat.mass)=="owner.x"] <- "own.ave.mass"
colnames(owner.sat.mass)[colnames(owner.sat.mass)=="satellite.x"] <- "sat.ave.mass"
colnames(owner.sat.mass)[colnames(owner.sat.mass)=="owner.y"] <- "own.max.mass"
colnames(owner.sat.mass)[colnames(owner.sat.mass)=="satellite.y"] <- "sat.max.mass"
owner.sat.mass

owner.sat.mass$ln.mean.mass <- log(owner.sat.mass$own.ave.mass/owner.sat.mass$sat.ave.mass)
owner.sat.mass$ln.max.mass <- log(owner.sat.mass$own.max.mass/owner.sat.mass$sat.max.mass)

focal.variables <- c("block", "ln.mean.mass", "ln.max.mass")
owner.sat.mass2 <- owner.sat.mass[focal.variables]
owner.sat.mass3 <-  gather(owner.sat.mass2, block)
owner.sat.mass3$block <- factor(owner.sat.mass3$block, levels = c("ln.mean.mass", "ln.max.mass"))

box2<- ggplot(data=owner.sat.mass3, aes(x=block, y=value, na.rm = TRUE)) +
  geom_boxplot(fill="darkgray", outlier.shape = NA) + geom_point(position= position_jitter(width=0.2), size=2.5, colour="black") +
  theme_bw(base_size = 12, base_family = "Helvetica") +
  labs(x = " ", y= "ln(owner mass/satellite mass)") +
  geom_abline(intercept = 0, slope = 0, linetype="dotted") +
  ggtitle("Size differences between owners and satellites for traps with satellites") +
  ylim(c(-1.6,1.6)) 
box2 + theme_bw.2 # figure 5b

owners.only.dat <- subset(exp.2019.dat, exp.2019.dat$owner.sat == "owner") # create subset dataset with only owners
owners.only.dat$cubemass <- owners.only.dat$mass.g^(1/3)

model.mass.owners <- glm(cubemass ~ sat.present, data = owners.only.dat)
plot(model.mass.owners)
bartlett.test(resid(model.mass.owners),owners.only.dat$sat.present)
plot(resid(model.mass.owners)~owners.only.dat$sat.present)
hist(resid(model.mass.owners))
shapiro.test(resid(model.mass.owners))
summary(model.mass.owners)

box3<- ggplot(data=owners.only.dat, aes(x=sat.present, y=cubemass)) +
  geom_boxplot() + geom_point(position= position_jitter(width=0.2), size=2.5, colour="darkgray") +
  theme_bw(base_size = 12, base_family = "Helvetica") +
  labs(x = " ", y= "Mass (g, cube-root transformed)") +
  ggtitle("Size differences of owners with and without satellites")
box3 +theme_bw.2 # alternative figure

#######################################

# Weight differences between owners and heterospecific satellites for the 5 traps with both spp present

bothspp.dat <- subset(exp.2019.dat, exp.2019.dat$sayi.and.orb == "yes")
bothspp.dat 
bothspp.dat$blck.spp.owner <- paste(bothspp.dat$block, bothspp.dat$species, bothspp.dat$owner.sat, sep="_")
bothspp.dat2 <- subset(bothspp.dat, bothspp.dat$blck.spp.owner == "11_sayi_owner" | bothspp.dat$blck.spp.owner == "11_orbicollis_satellite" | 
                         bothspp.dat$blck.spp.owner == "20_orbicollis_owner" | bothspp.dat$blck.spp.owner == "20_sayi_satellite" | 
                         bothspp.dat$blck.spp.owner == "33_orbicollis_owner" | bothspp.dat$blck.spp.owner == "33_sayi_satellite" | 
                         bothspp.dat$blck.spp.owner == "34_orbicollis_owner" | bothspp.dat$blck.spp.owner == "34_sayi_satellite" | 
                         bothspp.dat$blck.spp.owner == "40_orbicollis_owner" | bothspp.dat$blck.spp.owner == "40_sayi_satellite")

# calculate the mean and max mass for owners and heterospecific satellites within each bucket
library(dplyr)
os.owner.sat.ave.mass <- bothspp.dat2 %>% group_by(block, owner.sat) %>% summarise(mean_mass = mean(mass.g))
os.owner.sat.max.mass <- bothspp.dat2 %>% group_by(block, owner.sat) %>% summarise(max_mass = max(mass.g))

bothspp.model.ave <- lme(mean_mass ~ owner.sat, random =~ 1|block, data=os.owner.sat.ave.mass)
plot(bothspp.model.ave)
bartlett.test(resid(bothspp.model.ave), os.owner.sat.ave.mass$owner.sat)
plot(resid(bothspp.model.ave)~os.owner.sat.ave.mass$owner.sat)
hist(resid(bothspp.model.ave))
shapiro.test(resid(bothspp.model.ave))
summary(bothspp.model.ave)

bothspp.model.max <- lme(max_mass ~ owner.sat, random =~ 1|block, data=os.owner.sat.max.mass)
plot(bothspp.model.max)
bartlett.test(resid(bothspp.model.max), os.owner.sat.max.mass$owner.sat)
plot(resid(bothspp.model.max)~os.owner.sat.max.mass$owner.sat)
hist(resid(bothspp.model.max))
shapiro.test(resid(bothspp.model.max))
summary(bothspp.model.max)

library(tidyr) # reshape for plotting
os.owner.sat.ave.mass2 <-  spread(os.owner.sat.ave.mass, owner.sat, c(mean_mass))
os.owner.sat.max.mass2 <-  spread(os.owner.sat.max.mass, owner.sat, c(max_mass))
os.owner.sat.mass <- merge(os.owner.sat.ave.mass2, os.owner.sat.max.mass2, by = 'block')
os.owner.sat.mass
colnames(os.owner.sat.mass)[colnames(os.owner.sat.mass)=="owner.x"] <- "own.ave.mass"
colnames(os.owner.sat.mass)[colnames(os.owner.sat.mass)=="satellite.x"] <- "sat.ave.mass"
colnames(os.owner.sat.mass)[colnames(os.owner.sat.mass)=="owner.y"] <- "own.max.mass"
colnames(os.owner.sat.mass)[colnames(os.owner.sat.mass)=="satellite.y"] <- "sat.max.mass"
os.owner.sat.mass

os.owner.sat.mass$ln.mean.mass <- log(os.owner.sat.mass$own.ave.mass/os.owner.sat.mass$sat.ave.mass)
os.owner.sat.mass$ln.max.mass <- log(os.owner.sat.mass$own.max.mass/os.owner.sat.mass$sat.max.mass)

focal.variables <- c("block", "ln.mean.mass", "ln.max.mass")
os.owner.sat.mass2 <- os.owner.sat.mass[focal.variables]
os.owner.sat.mass3 <-  gather(os.owner.sat.mass2, block)
os.owner.sat.mass3$block <- factor(os.owner.sat.mass3$block, levels = c("ln.mean.mass", "ln.max.mass"))

box4<- ggplot(data=os.owner.sat.mass3, aes(x=block, y=value, na.rm = TRUE)) +
  geom_boxplot(fill="darkgray", outlier.shape = NA) + geom_point(position= position_jitter(width=0.2), size=2.5, colour="black") +
  theme_bw(base_size = 12, base_family = "Helvetica") +
  labs(x = " ", y= "ln(owner mass/satellite mass)") +
  geom_abline(intercept = 0, slope = 0, linetype="dotted") +
  ggtitle("Size differences between owners and satellites for traps with satellites") +
  ylim(c(-1,1)) 
box4 + theme_bw.2 # figure 5c


#########################################################
